from setuptools import setup

setup(name = 'lsc_distributions',
      version = '0.1',
      description = 'Gaussian and Binomial distributions',
      packages = ['lsc_distributions'],
      author = 'Lucian Stefan Craciun',
      author_email = 'lucyans_c@yahoo.com',
      zip_safe = False)
